@@ -1,10 +1,8 @@
 package Image::Select;
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Modules.
 use Class::Utils qw(set_params);
 use Error::Pure qw(err);
 use File::Basename qw(fileparse);
@@ -12,8 +10,7 @@ use File::Find::Rule qw(:MMagic);
 use Imager;
 use List::MoreUtils qw(none);
 
-# Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -282,11 +279,9 @@ Image::Select - Selecting image from images directory.
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use File::Spec::Functions qw(catfile);
  use File::Temp qw(tempfile tempdir);
  use Image::Random;
@@ -323,11 +318,9 @@ Image::Select - Selecting image from images directory.
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use File::Spec::Functions qw(catfile);
  use File::Temp qw(tempfile tempdir);
  use Image::Random;
@@ -390,25 +383,29 @@ Perl class for creating random image.
 
 Selecting image from list with checking.
 
+=item L<Image::Select::Date>
+
+Selecting image from images directory by date.
+
 =back
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Image-Select>
+L<https://github.com/michal-josef-spacek/Image-Select>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2015 Michal Špaček
+ © 2014-2020 Michal Josef Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
